![spice logo](https://raw.githubusercontent.com/maja-jablonska/spice/main/docs/img/spice_pink.svg)

A stellar spectra integration library.

The package can be installed using PyPI:

```bash
pip install stellar-spice
```

Paper is currently in prep.

# Documentation

Read the [docs](https://spice.readthedocs.io) here.

# Features implemented

- [x] Rotation
- [x] Spots
- [x] Pulsations
- [x] PHOEBE integration

## Dev log

Notebooks are being updated one by one.
